@@ -6,18 +6,13 @@ import re
 class Num2String():
 
     def __init__(self):
-        self.number_normalizer = NumberNormalizer()
+        self.number_rules = r'( +| -| )(((\d{1,30})?[./]\d{1,30} )|(\d{1,30} ))'
 
     def normalize(self, doc_string):
-        normalized_string = self.number_normalizer.find_number_part(text_line=doc_string)
+        normalized_string = self.find_number_part(text_line=doc_string)
 
         return normalized_string
 
-
-class NumberNormalizer():
-    def __init__(self):
-        self.number_rules = r'( +| -| )(((\d{1,30})?[./]\d{1,30} )|(\d{1,30} ))'
-
     def find_number_part(self, text_line):
         text_line = " "+text_line+" "
 
